@@ -1,5 +1,7 @@
 from typing import Dict, Optional
 
+from cryptocompsdk.blockchain.available.api import BlockchainAvailableCoinsAPI
+from cryptocompsdk.blockchain.history.api import BlockchainHistoryAPI
 from cryptocompsdk.coins.parse import Coins
 from cryptocompsdk.exchanges.info.api import ExchangeInfoAPI
 from cryptocompsdk.exchanges.symbols.api import ExchangeSymbolsAPI
@@ -22,6 +24,10 @@ class CryptoCompare(APIBase):
     exchange_symbols :class:`.ExchangeSymbolsAPI`
 
     exchange_info :class:`.ExchangeInfoAPI`
+
+    blockchain_available_coins :class:`.BlockchainAvailableCoinsAPI`
+
+    blockchain_history :class:`.BlockchainHistoryAPI`
     """
 
     def __init__(self, api_key: str, throttle: Optional[float] = None):
@@ -31,6 +37,8 @@ class CryptoCompare(APIBase):
         self.social = SocialAPI(api_key, throttle)
         self.exchange_symbols = ExchangeSymbolsAPI(api_key, throttle)
         self.exchange_info = ExchangeInfoAPI(api_key, throttle)
+        self.blockchain_available_coins = BlockchainAvailableCoinsAPI(api_key, throttle)
+        self.blockchain_history = BlockchainHistoryAPI(api_key, throttle)
 
         self._coin_response: Optional[Coins] = None
 
