@@ -25,3 +25,8 @@ ALL_EXCHANGE_URL = DATA_V3_ALL_URL + 'exchanges'
 
 # Exchange General Info API
 EXCHANGE_INFO_URL = DATA_URL + 'exchanges/general'
+
+# Blockchain API
+BLOCKCHAIN_BASE_URL = DATA_URL + 'blockchain/'
+BLOCKCHAIN_AVAILABLE_COINS_URL = BLOCKCHAIN_BASE_URL + 'list'
+BLOCKCHAIN_HISTORICAL_DAILY_URL = BLOCKCHAIN_BASE_URL + 'histo/day'
